*                         MICRON HSPICE MODEL
*
* Disclaimer: This software code and all associated documentation, comments
*             or other information (collectively "Software") is provided
*             "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*             ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*             INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*             RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*             FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*             SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*             THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*             MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*             RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*             ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*             OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*             EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*             LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*             SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*             OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*             ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*             EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*             Because some jurisdictions prohibit the exclusion or limitation
*             of liability for consequential or incidental damages, the above
*             limitation may not apply to you.
* 
*             Copyright 2011 Micron Technology, Inc. All rights reserved.
*
************** 32Megx8, 16Megx16  SDRAM **************************************
********Example HSPICE setup file for DQs)************************************
****
***********************************************************
****           ____                                       *
****      IN--|    \                                      *
****          |     }------PAD--\/\/\/--@@@@--|--PKG_OUT  *
****   ENOUT--|____/    |        R_pkg  L_pkg |           *
****                    |                    ===C_pkg     *
****             ___    |                     |           *
****            /  +|---|                    GND          *
**** RCVR_OUT--{    |                                     *
****            \___|-(ENOUT#)                            *
***********************************************************
****
**** This netlist is for the x8, x16 256Mb SDRAM
**** The input signals are IN (input signal) and ENOUT (output enable signal).
**** The I/O data is available on the signal PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.
****
**** NOTE: This spice file is not designed to match datasheet timing numbers.
****       Delay times are smaller than those given in the data sheets.
****
**** The .LIB statement selects the following simulation corners:
****   TT - Typ N,  Typ P,  Typical die capacitance
****   SS - Slow N, Slow P, Maximum die capacitance
****   FF - Fast N, Fast P, Minimum die capacitance
****
**** To run this simulation, the files "y66a_model.cnr" and "y66a_dqbuff.inc"
**** are required to be in the same directory as this netlist.
****
**** Commercial temperature settings are: Typical 50C, Slow 85C, Fast 0C
**** Industrial temperature settings are: Typical 50C, Slow 95C, Fast -40C
**** Automotive temperature settings are: Typical 50C, Slow 110C, Fast -40C
***********************************************************
.OPTIONS POST
.OPTIONS METHOD=GEAR
.OPTIONS GSHUNT=1E-12
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns '12*per' start=delay

.LIB "y66a_model.cnr" TT



.TITLE Nominal Full Drive

**** Temperature is for typical case (CT=50C, IT=50C, AT=50C)
.TEMP 50

***********************************************************
**** POWER SUPPLY PARAMETER 
***********************************************************
******Voltages for SDRAM
.PARAM  vccq_typ   = 3.300V
.PARAM  vccq_min   = 3.000V
.PARAM  vccq_max   = 3.600V

.PARAM  vcc_typ   = 3.300V
.PARAM  vcc_min   = 3.000V
.PARAM  vcc_max   = 3.600V


******vccr internal regulated power supply
.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V

.PARAM  gnd       = 0.000V
.PARAM  vssq      = 0.000V
.PARAM  vss       = 0.000V

**** Match up typ, min, or max voltages for corner sims
.PARAM  vccq      = vccq_typ
.PARAM  vcc       = vcc_typ
.PARAM  vccr      = vccr_typ

***********************************************************
Vvccq   vccq 0   DC = vccq
Vvcc    vcc  0   DC = vcc
Vvccr   vccr 0   DC = vccr 
Vvssq   vssq 0   DC = vssq
Vvss    vss  0   DC = vss
Vvtt    vtt  0   DC = '0.5*vccq'

***********************************************************
**** OUTPUT ENABLE SIGNAL  
***********************************************************
**** Active high for output, Active low for input

Ven    enout  0  DC = vccr

***********************************************************
**** INPUT SIGNAL  
***********************************************************
**** Input Stimulus Parameters
*.PARAM datarate = 100.00E6
*.PARAM datarate = 133.33E6
*.PARAM datarate = 143.33E6
.PARAM datarate = 166.67E6


.PARAM pulsewidth = '0.5/datarate - dataslew'
.PARAM per = '1/datarate'
.PARAM delay = 2ns
.PARAM dataslew = 150ps

**** Vin toggles the DQ at the datarate specified above
Vin    IN     0  LFSR vss vccr delay dataslew dataslew datarate 1 [5 2]

***********************************************************
**** TOP CELL:  y66a_dqbuff
***********************************************************

xi0 RCVR_OUT PAD ENOUT IN vss vccr vccq vssq vcc y66a_dqbuff


***********************************************************
**** PACKAGE CONNECTION
***********************************************************
**** Refer to the IBIS model for specific package parasitic values.

x_pkg_pad PAD PKG_OUT pkg  r=138.76m l=3.30nH c=1.02pF 

ctt PAD gnd C=50p


.SUBCKT pkg pad pkg_out r=0 l=0 c=0
r_pkg pad net1 R='r'
l_pkg net1 pkg_out L='l'
c_pkg pkg_out gnd C='c'
.ENDS pkg

***********************************************************
**** ALTER STATEMENTS
***********************************************************

.ALTER

.TITLE Weak

VFULLDRV FULLDRV gnd dc=vccr

.PARAM  vccq        = vccq_min
.PARAM  vcc         = vcc_min
.PARAM  vccr        = vccr_min

**** Temperature is for slow case (CT=85C, IT=95C, AT=110C)
.TEMP 85

.LIB "y66a_model.cnr" SS
***********************************************************
.ALTER

.TITLE Strong

.PARAM  vccq        = vccq_max
.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max

**** Temperature is for fast case (CT=0C, IT=-40C, AT=-40C)
.TEMP 0

.LIB "y66a_model.cnr" FF
***********************************************************
.ALTER

.TITLE Write Mode 

.PARAM  vccq        = vccq_typ
.PARAM  vcc         = vcc_typ
.PARAM  vccr        = vccr_typ

.TEMP 50
Ven       enout   0  DC = vss
Vpkg_out  pkg_out 0  PULSE 0 vccq delay dataslew dataslew pulsewidth per

***********************************************************
.END




